@@ -1,7 +1,7 @@
 package App::shcompgen;
 
-our $DATE = '2016-04-30'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2016-07-12'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -309,6 +309,10 @@ sub _detect_prog {
                 string => $content);
             $log->tracef("Perinci::CmdLine detection result: %s", $det_res);
             last unless $det_res->[2];
+
+            # pericmd-inline doesn't currently support self-completion
+            last if $det_res->[3]{'func.is_inline'};
+
             return [200, "OK", 1, {
                 "func.completer_command"=> $prog,
                 "func.completer_type"=> "Perinci::CmdLine",
@@ -689,7 +693,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.17 of App::shcompgen (from Perl distribution App-shcompgen), released on 2016-04-30.
+This document describes version 0.18 of App::shcompgen (from Perl distribution App-shcompgen), released on 2016-07-12.
 
 =head1 FUNCTIONS
 
